classdef ScenarioGraphic< handle
%ScenarioGraphic   Manages graphical behavior for all plottable
% entities in satelliteScenario

     
    %   Copyright 2020-2023 The MathWorks, Inc.

    methods
        function out=ScenarioGraphic
        end

        function out=get(~) %#ok<STOUT>
            %get    get property in object
        end

        function out=hide(~) %#ok<STOUT>
            %hide   Hide object from the Satellite Scenario Viewer
            %   hide(OBJ) hides the object OBJ from all open Satellite 
            %   Scenario Viewers. OBJ is an object (such as Satellite,
            %   Orbit, GroundStation, GroundTrack, CoordinateAxes,
            %   FieldOfView, Access, Link, or Pattern object) in the
            %   satellite scenario. If OBJ is a Satellite or a
            %   GroundStation object, then the associated Gimbal,
            %   ConicalSensor, Transmitter, and Receiver objects are also
            %   hidden from the viewers.
            %
            %   hide(OBJ, VIEWER) hides the object OBJ from the Satellite 
            %   Scenario Viewer specified by VIEWER.
            %
            %   % Example
            %
            %   % Hide the satellite in the scenario in from a Satellite 
            %   % Scenario Viewer
            %
            %   % Create a satellite scenario object.
            %   sc = satelliteScenario;
            %
            %   % Add a satellite to the scenario.
            %   semiMajorAxis = 10000000; % m
            %   eccentricity = 0;
            %   inclination = 0; % degrees
            %   rightAscensionOfAscendingNode = 0; % degrees
            %   argumentOfPeriapsis = 0; % degrees
            %   trueAnomaly = 0; % degrees
            %   sat = satellite(sc,semiMajorAxis, ...
            %       eccentricity, ...
            %       inclination, ...
            %       rightAscensionOfAscendingNode, ...
            %       argumentOfPeriapsis, ...
            %       trueAnomaly);
            %
            %   % Launch a Satellite Scenario Viewer and visualize. By
            %   % default, the satellite is visible in it.
            %   viewer = satelliteScenarioViewer(sc);
            %
            %   % Hide the satellite from the viewer.
            %   hide(sat,viewer);
            %
            %   See also <a href="matlab:help('matlabshared.satellitescenario.Viewer.showAll')">showAll</a>, <a href="matlab:help('matlabshared.satellitescenario.Viewer.hideAll')">hideAll</a>, <a href="matlab:help('matlabshared.satellitescenario.ScenarioGraphic.show')">show</a>
        end

        function out=set(~) %#ok<STOUT>
            %set    Set property in object
        end

        function out=show(~) %#ok<STOUT>
            %show   Show object in the Satellite Scenario Viewer
            %   show(OBJ) shows the object OBJ on all open Satellite 
            %   Scenario Viewers. OBJ is an object (such as a Satellite, 
            %   Orbit, GroundStation, GroundTrack, CoordinateAxes,
            %   FieldOfView, Access, Link, or Pattern object) in the
            %   satellite scenario. If OBJ is a Satellite or a
            %   GroundStation object, then the associated Gimbal,
            %   ConicalSensor, Transmitter, and Receiver objects are also
            %   displayed on the viewers.
            %
            %   show(OBJ, VIEWER) shows the object OBJ on the Satellite 
            %   Scenario Viewer specified by VIEWER.
            %
            %   % Example
            %
            %   % Show the satellite that was previously hidden in the 
            %   % Satellite Scenario Viewer
            %
            %   % Create a satellite scenario object.
            %   sc = satelliteScenario;
            %
            %   % Set AutoShow of the scenario to false so that objects
            %   % added to the scenario do not automatically get added to
            %   % the Satellite Scenario Viewer.
            %   sc.AutoShow = false;
            %
            %   % Launch a Satellite Scenario Viewer.
            %   viewer = satelliteScenarioViewer(sc);
            %
            %   % Add a satellite to the scenario.
            %   semiMajorAxis = 10000000; % m
            %   eccentricity = 0;
            %   inclination = 0; % degrees
            %   rightAscensionOfAscendingNode = 0; % degrees
            %   argumentOfPeriapsis = 0; % degrees
            %   trueAnomaly = 0; % degrees
            %   sat = satellite(sc,semiMajorAxis, ...
            %       eccentricity, ...
            %       inclination, ...
            %       rightAscensionOfAscendingNode, ...
            %       argumentOfPeriapsis, ...
            %       trueAnomaly);
            %
            %   % Because AutoShow of the scenario is false, the satellite 
            %   % has not been automatically added to the Satellite 
            %   % Scenario Viewer. Therefore, call "show" to visualize the 
            %   % satellite in the viewer.
            %   show(sat);
            %
            %   See also <a href="matlab:help('matlabshared.satellitescenario.Viewer.showAll')">showAll</a>, <a href="matlab:help('matlabshared.satellitescenario.ScenarioGraphic.hide')">hide</a>, <a href="matlab:help('matlabshared.satellitescenario.Viewer.hideAll')">hideAll</a>
        end

    end
end
